#! /usr/bin/python
# -*- coding:UTF-8 -*-
#
#------------------------------------------------------------------------------
# TrasMiSIG  -  Software libre para consultar y visualizar rutas ptimas en una
# red de transporte masivo compuesta por estaciones y segmentos. Utiliza
# PostgreSQL/PostGIS y PyQGIS.
#
# Original sources Copyright (c) 2006 by Tim Sutton
# Ported to Python by Martin Dobias
# Copyright (C) 2009  Germn Carrillo
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#------------------------------------------------------------------------------

import sys, os

from PyQt4.QtGui import QApplication, QStyleFactory, QDesktopWidget, QMessageBox
from qgis.core import QgsApplication

from logica_trasmisig import Visor
from conexion_postgresql import ConexionPgSQL
from config import *


def main( argv ):
    """ Mtodo principal de TrasMiSIG """
    app = QApplication( argv )
    app.setStyle( QStyleFactory.create( 'Cleanlooks' ) )
    screen = QDesktopWidget().screenGeometry() # Para centrar ventanas

    # Validar que exista conexin a la BD de TrasMiSIG
    conexionBD = ConexionPgSQL()

    if not conexionBD.conectado:
        msg = QMessageBox( QMessageBox.Critical, 'No se encuentra la Base de ' \
            + 'Datos "' + BD + '"', 'TrasMiSIG necesita una base de datos de ' \
            + 'PostgreSQL para funcionar correctamente.\n\nRevisa la ' \
            + 'documentacin, instala la base de datos en PostgreSQL y ' \
            + 'vuelve a ejecutar TrasMiSIG.' )
        msg.addButton( 'Aceptar', QMessageBox.AcceptRole )

        size =  msg.geometry()
        msg.move( ( screen.width() - size.width() )/2,
            ( screen.height() - size.height() )/2)

        msg.exec_()
        retval = 0
    else:
        if os.name == "nt":
            qgis_prefix = QGIS_PREFIX_WIN
        else:
            qgis_prefix = QGIS_PREFIX_LINUX

        # Inicializar las librerias de QGIS
        QgsApplication.setPrefixPath( qgis_prefix, True )
        QgsApplication.initQgis()

        # Crear y mostrar la ventana principal
        miVisor = Visor()
        size =  miVisor.geometry()
        miVisor.move( ( screen.width() - size.width() )/2,
            ( screen.height() - size.height() )/2)
        miVisor.show()

        # Ejecutar un loop para correr el programa
        retval = app.exec_()

        # Salir de QGIS
        QgsApplication.exitQgis()

    # Salir
    sys.exit( retval )

if __name__ == "__main__":
    # Si el modulo es importado __name__=Visor, si es ejecutado: __main__
    main( sys.argv )